@@ -38,11 +38,11 @@
 //--------------------------------------------
 - free
 {
-    free (inpLy);
-    free (Wgts);
-    free (opLy);
-    [self drop];
-    return nil;
+  xfree (inpLy);
+  xfree (Wgts);
+  xfree (opLy);
+  [self drop];
+  return nil;
 }
 
 //-----------------------------------------------------
