@@ -32,7 +32,7 @@
 {		// Randomize weights, result [-1,1]
   unsigned i;
   for (i = 0; i < numNeurons * numNeurons; i++)
-    weights[i]=(float)[uniformDblRand getDoubleWithMin:-1.0L withMax: 1.0L];
+    weights[i] = (float)[uniformDblRand getDoubleWithMin:-1.0L withMax: 1.0L];
   
   // Set biases to 0
   for (i = 0; i < numNeurons; i++)
@@ -62,12 +62,12 @@
 
 - free
 {
-  free (y);
-  free (yPlus);
-  free (inputs);
-  free (bias);
-  free (weights);
-  free (taus);
+  xfree (y);
+  xfree (yPlus);
+  xfree (inputs);
+  xfree (bias);
+  xfree (weights);
+  xfree (taus);
   [self drop];
 
   return nil;
@@ -96,7 +96,7 @@
     {
       yPlus[i] = inpVec[i] - y[i];
       for (j = 0; j < numNeurons; j++)
-        yPlus[i] += weights[j*numNeurons+i]*sigmoid(y[j]-bias[j]);
+        yPlus[i] += weights[j * numNeurons + i] * sigmoid (y[j] - bias[j]);
       y[i] += yPlus[i]/taus[i];
     }
   return self;
@@ -104,7 +104,7 @@
 
 - getActivation: (float *)_act
 {
-  memcpy ( _act, y, numNeurons * sizeof(float));
+  memcpy (_act, y, numNeurons * sizeof (float));
 
   return self;
 }
