@@ -16,6 +16,7 @@
 #import <simtools.h>
 #import <simtoolsgui.h>
 #import <random.h>
+#import <gui.h>
 
 #include "SOMplus.h"
 
@@ -32,7 +33,7 @@ char *Colors[] = {
   "red", "orange", "yellow", "green", "blue", "purple", "grey50", "black",
 };
 
-void
+int
 main (int argc, const char **argv)
 {
   unsigned numNeurons = 10;
@@ -163,4 +164,5 @@ main (int argc, const char **argv)
       
       i++;
     }
+  exit (0);
 }
